# BAGO

[![Generic badge](https://img.shields.io/badge/BAGO-ver_1.0-<COLOR>.svg)](https://github.com/Waddlessss/bago/)
![Maintainer](https://img.shields.io/badge/maintainer-Huaxu_Yu-blue)
[![PyPI Downloads](https://img.shields.io/pypi/dm/bago.svg?label=PyPI%20downloads)](https://pypi.org/project/bago/)

BAGO is a Bayesian optimization strategy for LC gradient optimization for MS-based small molecule analysis. Check out our [YouTube video](https://youtu.be/btNblKBXxk8)

### BAGO enables

**Highly efficient gradient optimization**

- Find an optimal gradient for your LC-MS/MS analysis within 10 runs.
- Wonder why BAGO is efficient? Read more about [acquisition functions](https://bago.readthedocs.io/en/latest/acq-func.html).

**Omics-scale evaluation on compound separation**

- Separation efficiency was defined to evaluate the performance of a gradient.
- Wonder how omics-scale evaluation is achieved? Read more about [encodings](https://bago.readthedocs.io/en/latest/encodings.html).

**Broader discovery of chemical space**

- Expand your discovery of chemical space by improving identification and quantification.
- Wonder how BAGO can help you? Read more about [applications](https://bago.readthedocs.io/en/latest/applications.html).

&nbsp;
&nbsp;

# BAGO Windows Software

BAGO Windows software is freely available from the [GitHub release page](https://github.com/huaxuyu/bago/releases). A user manual in .pdf format is included with the software.

The software is designed to be simple, clear, and intuitive. BAGO has a graphical user interface as shown below.

<img src = "/pictures/BAGO_software_main.jpg" width = "850" >

&nbsp;
&nbsp;

# _bago_ Python package

_bago_ is a Python package for supporting the proposed Bayesian Optimization framework of LC gradient optimization.

_bago_ covers the proposed features needed in creating a gradient optimization workflow based on Bayesian optimization. Depending on your use case, _bago_ can be used in different ways:

- Perform LC gradient optimization in programmtic envrionment
- Model LC-MS experiment to evaluate compound separation performance
- Optimize the default pipeline to adpat a special gradient optimization scenario
- Further development of the proposed Bayesian optimization strategy
- Extend the corrent stategy to other LC-based analytical platforms

&nbsp;
&nbsp;

# Accessibility

- **Documentation:** https://bago.readthedocs.io/en/latest/
- **Source code:** https://github.com/huaxuyu/bago
- **Bug reports:** https://github.com/huaxuyu/bago/issues

&nbsp;
&nbsp;

# Please cite

Yu, H., Biswas, P., Rideout, E., Cao, Y., & Huan, T. (2023). Bayesian optimization of separation gradients to maximize the performance of untargeted LC-MS. bioRxiv, 2023-09.

[BAGO manuscript](https://www.biorxiv.org/content/10.1101/2023.09.08.556930v1)
